
import os

from tarmac.pidfile import make_pidfile, get_pid, remove_pidfile
from tarmac.tests import TarmacTestCase


class TestPidFile(TarmacTestCase):
    """Tests for the functions in the pidfile.py module."""

    def test_make_pidfile(self):
        self.assertFalse(os.path.exists(self.config.PID_FILE))
        make_pidfile()
        self.assertTrue(os.path.exists(self.config.PID_FILE))

    def test_make_pidfile_raises_if_exists(self):
        self.assertFalse(os.path.exists(self.config.PID_FILE))
        make_pidfile()
        self.assertRaises(RuntimeError, make_pidfile)

    def test_get_pid(self):
        self.assertFalse(os.path.exists(self.config.PID_FILE))
        make_pidfile()
        self.assertEqual(os.getpid(), get_pid())

    def test_remove_pidfile(self):
        self.assertFalse(os.path.exists(self.config.PID_FILE))
        make_pidfile()
        self.assertTrue(os.path.exists(self.config.PID_FILE))
        remove_pidfile()
        self.assertFalse(os.path.exists(self.config.PID_FILE))
